@@ -1,9 +1,5 @@
 
-## @knitr include=FALSE
-library(knitr);render_html()
-
-
-## @knitr illusions_cafe_wall
+## ----illusions_cafe_wall-------------------------------------------------
 library(grid)
 rs <- expand.grid(x = seq(0, 1, 1/10), y = seq(0, 1, 1/10))
 grid.rect(rs$x, rs$y, 1/10/2, 1/10/2, gp = gpar(fill = "black", col = NA))
@@ -12,7 +8,7 @@ ls <- expand.grid(x = 0:1, y = seq(0, 1, 1/20) - 1/20/2)
 grid.polyline(ls$x, ls$y, id = gl(nrow(ls)/2, 2), gp = gpar(col = "grey50", lwd = 1))
 
 
-## @knitr illusions_ouchi
+## ----illusions_ouchi-----------------------------------------------------
 grid.newpage()
 nx <- 10; ny <- 30
 rs <- expand.grid(x = seq(0, 1, 1/nx/2), y = seq(0, 1, 1/ny/2))
@@ -21,7 +17,7 @@ rs <- expand.grid(x = seq(0.25, 0.75, 1/nx/2), y = seq(0.25, 0.75, 1/ny/2))
 grid.rect(rs$y, rs$x, 1/ny/2, 1/nx/2, gp = gpar(col = NA, fill = c("black", "white")))
 
 
-## @knitr illusions_fraser
+## ----illusions_fraser----------------------------------------------------
 library(plyr)
 grid.newpage()
 n <- 10; ny <- 8; L <- 0.01; c <- seq(0, 1, length = n); d <- 1.2*diff(c)[1]/2
@@ -44,7 +40,7 @@ l_ply(1:ny, function(i) {n
 })
 
 
-## @knitr illusions_fraser_wilcox
+## ----illusions_fraser_wilcox---------------------------------------------
 grid.newpage()
 No <- 3
 wo <- 1/3/2
@@ -70,7 +66,7 @@ for (y0 in seq(0, 1, len = 10)) {
 }
 
 
-## @knitr illusions_parallel_lines
+## ----illusions_parallel_lines--------------------------------------------
 x=1:100
 y=1/log10(x)
 y2=y+.2
